/*
 *
 * Perforce/Java Integration Layer
 * Copyright (C) 2001-2002 David Freels
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation;
 * version 2.1 of the License.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

package com.dafreels.vcs.command;

/**
 *
 * @author  David Freels
 * @version 1.0
 */

public interface PropertyInterface 
{
  /** Returns the Perforce user name to use when
   * executing commands to the server.
   * @return A string representing the Perforce user name
   */  
  public String getUserName();
  /** Returns the Perforce password to use when
   * executing commands to the server.
   * @return A string representing the Perforce password
   */  
  public String getPassword();
  /** Returns the Perforce client spec to use when
   * executing commands to the server.
   * @return A string representing the Perforce client spec
   */  
  public String getClientSpec();
  /** Returns the Perforce port to use when
   * executing commands to the server.
   * @return A string representing the Perforce port
   */  
  public String getPort();
  /** Returns the path to the Perforce executable.
   * @return A string representing the Perforce executable location
   */  
  public String getExecutable();
  /** A boolean flag signaling whether to include
   * a debug switch with the Perforce command.
   * @return True if the p4 command should show debug info
   */  
  public boolean debug();
  /** The debug level (1-7) to be used with the
   * Perforce command tool.
   * @return An int between 1 and 7 specifying the debug level
   */  
  public int getDebugLevel();
}

